@@ -17,14 +17,12 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_elastictranscoder.paginator import (
+from .paginator import (
     ListJobsByPipelinePaginator,
     ListJobsByStatusPaginator,
     ListPipelinesPaginator,
     ListPresetsPaginator,
 )
-from mypy_boto3_elastictranscoder.waiter import JobCompleteWaiter
-
 from .type_defs import (
     AudioParametersTypeDef,
     CreateJobOutputTypeDef,
@@ -49,6 +47,7 @@ from .type_defs import (
     UpdatePipelineStatusResponseTypeDef,
     VideoParametersTypeDef,
 )
+from .waiter import JobCompleteWaiter
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -80,7 +79,7 @@ class Exceptions:
 
 class ElasticTranscoderClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -89,14 +88,14 @@ class ElasticTranscoderClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def cancel_job(self, Id: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.cancel_job)
-        [Show boto3-stubs documentation](./client.md#cancel-job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.cancel_job)
+        [Show boto3-stubs documentation](./client.md#cancel_job)
         """
 
     def create_job(
@@ -111,8 +110,8 @@ class ElasticTranscoderClient:
         UserMetadata: Dict[str, str] = None,
     ) -> CreateJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_job)
-        [Show boto3-stubs documentation](./client.md#create-job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_job)
+        [Show boto3-stubs documentation](./client.md#create_job)
         """
 
     def create_pipeline(
@@ -127,8 +126,8 @@ class ElasticTranscoderClient:
         ThumbnailConfig: "PipelineOutputConfigTypeDef" = None,
     ) -> CreatePipelineResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_pipeline)
-        [Show boto3-stubs documentation](./client.md#create-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_pipeline)
+        [Show boto3-stubs documentation](./client.md#create_pipeline)
         """
 
     def create_preset(
@@ -141,20 +140,20 @@ class ElasticTranscoderClient:
         Thumbnails: "ThumbnailsTypeDef" = None,
     ) -> CreatePresetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_preset)
-        [Show boto3-stubs documentation](./client.md#create-preset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_preset)
+        [Show boto3-stubs documentation](./client.md#create_preset)
         """
 
     def delete_pipeline(self, Id: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_pipeline)
-        [Show boto3-stubs documentation](./client.md#delete-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_pipeline)
+        [Show boto3-stubs documentation](./client.md#delete_pipeline)
         """
 
     def delete_preset(self, Id: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_preset)
-        [Show boto3-stubs documentation](./client.md#delete-preset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_preset)
+        [Show boto3-stubs documentation](./client.md#delete_preset)
         """
 
     def generate_presigned_url(
@@ -165,66 +164,66 @@ class ElasticTranscoderClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def list_jobs_by_pipeline(
         self, PipelineId: str, Ascending: str = None, PageToken: str = None
     ) -> ListJobsByPipelineResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_pipeline)
-        [Show boto3-stubs documentation](./client.md#list-jobs-by-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_pipeline)
+        [Show boto3-stubs documentation](./client.md#list_jobs_by_pipeline)
         """
 
     def list_jobs_by_status(
         self, Status: str, Ascending: str = None, PageToken: str = None
     ) -> ListJobsByStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_status)
-        [Show boto3-stubs documentation](./client.md#list-jobs-by-status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_status)
+        [Show boto3-stubs documentation](./client.md#list_jobs_by_status)
         """
 
     def list_pipelines(
         self, Ascending: str = None, PageToken: str = None
     ) -> ListPipelinesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_pipelines)
-        [Show boto3-stubs documentation](./client.md#list-pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_pipelines)
+        [Show boto3-stubs documentation](./client.md#list_pipelines)
         """
 
     def list_presets(
         self, Ascending: str = None, PageToken: str = None
     ) -> ListPresetsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_presets)
-        [Show boto3-stubs documentation](./client.md#list-presets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_presets)
+        [Show boto3-stubs documentation](./client.md#list_presets)
         """
 
     def read_job(self, Id: str) -> ReadJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_job)
-        [Show boto3-stubs documentation](./client.md#read-job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_job)
+        [Show boto3-stubs documentation](./client.md#read_job)
         """
 
     def read_pipeline(self, Id: str) -> ReadPipelineResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_pipeline)
-        [Show boto3-stubs documentation](./client.md#read-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_pipeline)
+        [Show boto3-stubs documentation](./client.md#read_pipeline)
         """
 
     def read_preset(self, Id: str) -> ReadPresetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_preset)
-        [Show boto3-stubs documentation](./client.md#read-preset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_preset)
+        [Show boto3-stubs documentation](./client.md#read_preset)
         """
 
     def test_role(
         self, Role: str, InputBucket: str, OutputBucket: str, Topics: List[str]
     ) -> TestRoleResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.test_role)
-        [Show boto3-stubs documentation](./client.md#test-role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.test_role)
+        [Show boto3-stubs documentation](./client.md#test_role)
         """
 
     def update_pipeline(
@@ -239,22 +238,22 @@ class ElasticTranscoderClient:
         ThumbnailConfig: "PipelineOutputConfigTypeDef" = None,
     ) -> UpdatePipelineResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline)
-        [Show boto3-stubs documentation](./client.md#update-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline)
+        [Show boto3-stubs documentation](./client.md#update_pipeline)
         """
 
     def update_pipeline_notifications(
         self, Id: str, Notifications: "NotificationsTypeDef"
     ) -> UpdatePipelineNotificationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_notifications)
-        [Show boto3-stubs documentation](./client.md#update-pipeline-notifications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_notifications)
+        [Show boto3-stubs documentation](./client.md#update_pipeline_notifications)
         """
 
     def update_pipeline_status(self, Id: str, Status: str) -> UpdatePipelineStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_status)
-        [Show boto3-stubs documentation](./client.md#update-pipeline-status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_status)
+        [Show boto3-stubs documentation](./client.md#update_pipeline_status)
         """
 
     @overload
@@ -262,7 +261,7 @@ class ElasticTranscoderClient:
         self, operation_name: Literal["list_jobs_by_pipeline"]
     ) -> ListJobsByPipelinePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline)[Show boto3-stubs documentation](./paginators.md#listjobsbypipelinepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline)[Show boto3-stubs documentation](./paginators.md#listjobsbypipelinepaginator)
         """
 
     @overload
@@ -270,22 +269,22 @@ class ElasticTranscoderClient:
         self, operation_name: Literal["list_jobs_by_status"]
     ) -> ListJobsByStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus)[Show boto3-stubs documentation](./paginators.md#listjobsbystatuspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus)[Show boto3-stubs documentation](./paginators.md#listjobsbystatuspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines)[Show boto3-stubs documentation](./paginators.md#listpipelinespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines)[Show boto3-stubs documentation](./paginators.md#listpipelinespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_presets"]) -> ListPresetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets)[Show boto3-stubs documentation](./paginators.md#listpresetspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets)[Show boto3-stubs documentation](./paginators.md#listpresetspaginator)
         """
 
     def get_waiter(self, waiter_name: Literal["job_complete"]) -> JobCompleteWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elastictranscoder.html#ElasticTranscoder.Waiter.job_complete)[Show boto3-stubs documentation](./waiters.md#jobcompletewaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elastictranscoder.html#ElasticTranscoder.Waiter.job_complete)[Show boto3-stubs documentation](./waiters.md#jobcompletewaiter)
         """
